function S = Objective(params, MDL, data)
    % Objective.m
    % This file implements the Objective function used for optimization as
    % described in the document titled "EIS Model Fitting and Analysis". 
    %
    % Parameters 
    % @params: Set of model parameters to use for impedance calculation.
    % @MDL: Function handle to battery model to be used. 
    % @data: Experimental impedance data to compare. 
    %
    % Author: Marvin Messing, CMHT, McMaster University
    % Date: July 26, 2017

    Z = MDL(data.Frequency*1000, params);

    RE = real(Z);
    IMG = -1*imag(Z);

    % Unit weighting
    w.Real = ones(length(RE));
    w.Imaginary = ones(length(IMG));

    % Modulus weighting
    % w.Real = sqrt((RE.^2) + (IMG.^2))';
    % w.Imaginary = sqrt((RE.^2) + (IMG.^2))';

    % Proportional weighting
    % w.Real = 1/(RE.^2);
    % w.Imaginary = 1/(IMG.^2);

    S = sum(w.Real*(data.Real-RE).^2 + w.Imaginary*(data.Imaginary-IMG).^2);

end

