function Z = RZARCCPE_MDL(f, model_parameters)
    % RZARCCPE_MDL.m
    % This file implements the R-ZARC-CPE model impedance equation as described in
    % the document titled "EIS Model Fitting and Analysis". 
    %
    % Parameters 
    % @f: Vector of frequencies to model.
    % @model_parameters: Vector of model parameters. 
    %
    % Author: Marvin Messing, CMHT, McMaster University
    % Date: July 26, 2017

    L = model_parameters(1);
    Rs = model_parameters(2);
    Rp = model_parameters(3);
    Qp = model_parameters(4);
    a = model_parameters(5);
    Qd = model_parameters(6); 
    b = model_parameters(7);

    tau = (Rp*Qp)^(1/a);

    s = size(f);

    w = 2*pi*f;
    
    Z = 1i*w*L + Rs*ones(s) + ...
        (Rp*ones(s))./(1+(1i*w*tau).^a) + ...
        (ones(s))./(Qd*(1i*w).^b);
end

